==> okta-sdk-api-19.0.1-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/IdpPolicyRuleAction.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.IdpPolicyRuleActionIdp;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * IdpPolicyRuleAction
 */
@JsonPropertyOrder({ IdpPolicyRuleAction.JSON_PROPERTY_IDP })
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class IdpPolicyRuleAction implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_IDP = "idp";
    private IdpPolicyRuleActionIdp idp;

    public IdpPolicyRuleAction() {
    }

    public IdpPolicyRuleAction idp(IdpPolicyRuleActionIdp idp) {

        this.idp = idp;
        return this;
    }

    /**
     * Get idp
     *
     * @return idp
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_IDP)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public IdpPolicyRuleActionIdp getIdp() {
        return idp;
    }

    @JsonProperty(JSON_PROPERTY_IDP)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setIdp(IdpPolicyRuleActionIdp idp) {
        this.idp = idp;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        IdpPolicyRuleAction idpPolicyRuleAction = (IdpPolicyRuleAction) o;
        return Objects.equals(this.idp, idpPolicyRuleAction.idp);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(idp);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class IdpPolicyRuleAction {\n");
        sb.append("    idp: ").append(toIndentedString(idp)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-20.0.1-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/IdpPolicyRuleAction.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.IdpPolicyRuleActionIdp;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * IdpPolicyRuleAction
 */
@JsonPropertyOrder({ IdpPolicyRuleAction.JSON_PROPERTY_IDP })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-01-23T09:50:29.349096-06:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class IdpPolicyRuleAction implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_IDP = "idp";
    private IdpPolicyRuleActionIdp idp;

    public IdpPolicyRuleAction() {
    }

    public IdpPolicyRuleAction idp(IdpPolicyRuleActionIdp idp) {

        this.idp = idp;
        return this;
    }

    /**
     * Get idp
     *
     * @return idp
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_IDP)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public IdpPolicyRuleActionIdp getIdp() {
        return idp;
    }

    @JsonProperty(JSON_PROPERTY_IDP)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setIdp(IdpPolicyRuleActionIdp idp) {
        this.idp = idp;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        IdpPolicyRuleAction idpPolicyRuleAction = (IdpPolicyRuleAction) o;
        return Objects.equals(this.idp, idpPolicyRuleAction.idp);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(idp);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class IdpPolicyRuleAction {\n");
        sb.append("    idp: ").append(toIndentedString(idp)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
